# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 创建往来单位请求体实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 创建往来单位请求体实体
class CreatePartnerContent(ChanjetContent):

    def __init__(self, code, name, shorthand, partner_abb_name, partner_type_code, partner_class_code):
        self.dto = self.Dto(code, name, shorthand, partner_abb_name, partner_type_code, partner_class_code)

    class Dto:

        def __init__(self, code, name, shorthand, partner_abb_name, partner_type_code, partner_class_code):
            """
            往来单位实体初始化方法
            :param code: 往来单位编码
            :type code: str
            :param name: 往来单位名称
            :type name: str
            :param shorthand: 助记码
            :type shorthand: str
            :param partner_abb_name: 简称
            :type partner_abb_name: str
            :param partner_type_code: 往来单位性质编码
            :type partner_type_code: str
            :param partner_class_code: 往来单位所属类别编码
            :type partner_class_code: str
            """

            self.Code = code
            self.Name = name
            self.Shorthand = shorthand
            self.PartnerAbbName = partner_abb_name
            self.PartnerType = self.PartnerTypeInfo(partner_type_code)
            self.PartnerClass = self.PartnerClassInfo(partner_class_code)

        class PartnerClassInfo:

            def __init__(self, partner_class_code):
                self.Code = partner_class_code

        class PartnerTypeInfo:

            def __init__(self, partner_type_code):
                self.Code = partner_type_code



# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 通用报表查询返回值实体
from chanjet_openapi_python_sdk.chanjet_response import ChanjetResponse


class QueryReportDataResponse(ChanjetResponse):

    def __init__(self, data=None):
        self.ReportName = ''
        self.DataSource = DataSource()
        self.ColumnSource = ColumnSource()
        self.Pages = 0
        self.PageIndex = 0
        self.PageSize = 0
        self.TotalRecords = 1
        self.TaskSessionID = ''
        self.SolutionID = ''
        self.ErrorMessage = ''
        self.ErrorCode = ''
        self.ElapsedTime = 0
        self.WeakTypeDtoName = ''
        self.DtoClassName = ''
        self.IsWeakType = False
        self.AliName = ''
        self.Status = 0
        self.EnableHasChanged = False
        self.ChangedProperty = []
        self.DynamicPropertyKeys = []
        self.DynamicPropertyValues = []
        self.ID = ''
        self.DeleteID = ''
        self.Name = ''
        self.Code = ''
        self.Updated = ''
        self.UpdatedBy = ''
        self.InnerSearchLevel = 0
        self.RecordChange = True
        self.InnerPropInParentRecure = ''
        self.Ts = 0
        self.CaseSensitive = False
        self.RecordDynamicNullValue = False
        self.data = ''
        if data:
            self.__dict__ = data

    def __str__(self):
        return str(self.__dict__)


class DataSource:

    def __init__(self):
        self.Rows = [self.Row()]

    class Row:

        def __init__(self):
            self.voucherdate = ''
            self.saleDeliveryCode = ''
            self.partnerCode = ''
            self.partnerName = ''
            self.GroupLevel = ''
            self.rowType = ''
            self.reportRowType = ''


class ColumnSource:

    def __init__(self):
        self.Rows = [self.Row()]

    class Row:

        def __init__(self):
            self.FieldName = ''
            self.Title = ''
            self.ParentFieldName = ''



# -*- coding: utf-8 -*-
# @Time    : 2021/8/9 16:32
# @Author  : zc
# @Desc    : 获取租户token请求体实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 获取租户token请求体实体
class GetTenantTokenContent(ChanjetContent):

    def __init__(self, tenant_id, app_name, scope='auth_all'):
        """
        获取租户token实体初始化方法
        :param tenant_id: 租户ID
        :type tenant_id: str
        :param app_name: 畅捷通内应用名
        :type app_name: str
        :param scope: 授权范围
        :type scope: str
        """

        self.tenantId = tenant_id
        self.appName = app_name
        self.scope = scope



# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 创建销货单的请求体实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 创建销货单的请求体实体
class CreateSaleDeliveryContent(ChanjetContent):

    def __init__(self, voucher_date, external_code, customer_code, invoice_type_code, address, link_man, contact_phone,
                 header_dynamic_property_keys, header_dynamic_property_values):
        self.dto = self.Dto(voucher_date, external_code, customer_code, invoice_type_code, address, link_man, contact_phone,
                            header_dynamic_property_keys, header_dynamic_property_values)

    class Dto:

        def __init__(self, voucher_date, external_code, customer_code, invoice_type_code, address, link_man, contact_phone,
                     header_dynamic_property_keys, header_dynamic_property_values):
            """
            销货单实体初始化方法
            :param voucher_date: 单据日期
            :type voucher_date: str
            :param external_code: 外部系统单据编码
            :type external_code: str
            :param customer_code: 客户编码
            :type customer_code: str
            :param invoice_type_code: 票据类型编码
            :type invoice_type_code: str
            :param address: 送货地址
            :type address: str
            :param link_man: 联系人
            :type link_man: str
            :param contact_phone: 联系电话
            :type contact_phone: str
            :param header_dynamic_property_keys: 表头动态属性
            :type header_dynamic_property_keys: list
            :param header_dynamic_property_values: 表头动态属性值
            :type header_dynamic_property_values: list
            """

            self.VoucherDate = voucher_date
            self.ExternalCode = external_code
            self.Customer = self.CustomerInfo(customer_code)
            self.InvoiceType = self.InvoiceTypeInfo(invoice_type_code)
            self.Address = address
            self.LinkMan = link_man
            self.ContactPhone = contact_phone
            self.DynamicPropertyKeys = header_dynamic_property_keys
            self.DynamicPropertyValues = header_dynamic_property_values
            # 销货单明细
            self.SaleDeliveryDetails = []

        class CustomerInfo:

            def __init__(self, customer_code):
                self.Code = customer_code

        class InvoiceTypeInfo:

            def __init__(self, invoice_type_code):
                self.Code = invoice_type_code


# 销货单明细实体
class SaleDeliveryDetail:

    def __init__(self, inventory_code, unit_name, quantity, orig_price, orig_tax_amount, detail_dynamic_property_keys, detail_dynamic_property_values):
        """
        销货单明细实体初始化方法
        :param inventory_code: 存货编码
        :type inventory_code: str
        :param unit_name: 计量单位名称
        :type unit_name: str
        :param quantity: 数量
        :type quantity: float
        :param orig_price: 报价
        :type orig_price: float
        :param orig_tax_amount: 原币含税金额
        :type orig_tax_amount: float
        :param detail_dynamic_property_keys: 明细行动态属性
        :type detail_dynamic_property_keys: list
        :param detail_dynamic_property_values: 明细行动态属性值
        :type detail_dynamic_property_values: list
        """

        self.Inventory = self.InventoryInfo(inventory_code)
        self.Unit = self.UnitInfo(unit_name)
        self.Quantity = quantity
        self.OrigPrice = orig_price
        self.OrigTaxAmount = orig_tax_amount
        self.DynamicPropertyKeys = detail_dynamic_property_keys
        self.DynamicPropertyValues = detail_dynamic_property_values

    class InventoryInfo:

        def __init__(self, inventory_code):
            self.Code = inventory_code

    class UnitInfo:

        def __init__(self, unit_name):
            self.Name = unit_name



# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 现存量查询条件的请求实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 现存量查询条件的请求实体
class QueryCurrentStockContent(ChanjetContent):

    def __init__(self, code, name, warehouse_code, inventory_code, is_warehouse, is_inventory, is_inv_property):
        self.param = self.Params(code, name, warehouse_code, inventory_code, is_warehouse, is_inventory, is_inv_property)

    class Params:

        def __init__(self, warehouse_code, inventory_code, page_size, page_index, is_warehouse, is_inventory, is_inv_property):
            """
            现存量查询条件实体初始化方法
            :param warehouse_code: 仓库编码
            :type warehouse_code: str
            :param inventory_code: 存货编码
            :type inventory_code: str
            :param page_size: 分页查询每页数量
            :type page_size: int
            :param page_index: 分页查询的页号
            :type page_index: int
            :param is_warehouse: 是否按照仓库分组
            :type is_warehouse: bool
            :param is_inventory: 是否按照存货分组
            :type is_inventory: bool
            :param is_inv_property: 是否按照销售属性分组
            :type is_inv_property: bool
            """

            self.Warehouse = [self.WarehouseInfo(warehouse_code)]
            self.Inventory = [self.InventoryInfo(inventory_code)]
            self.PageSize = page_size
            self.PageIndex = page_index
            self.GroupInfo = self.GroupList(is_warehouse, is_inventory, is_inv_property)

        class WarehouseInfo:

            def __init__(self, warehouse_code):
                self.Code = warehouse_code

        class InventoryInfo:

            def __init__(self, inventory_code):
                self.Code = inventory_code

        class GroupList:

            def __init__(self, is_warehouse, is_inventory, is_inv_property):
                self.Warehouse = is_warehouse
                self.Inventory = is_inventory
                self.InvProperty = is_inv_property



# -*- coding: utf-8 -*-
# @Time    : 2021/8/10 16:57
# @Author  : zc
# @Desc    : 使用用户永久授权码获取token请求类
from chanjet_openapi_python_sdk.chanjet_request import ChanjetRequest


class GetTokenByPermanentCodeRequest(ChanjetRequest):

    def get_http_method(self):
        return 'post'



# -*- coding: utf-8 -*-
# @Time    : 2021/8/9 11:18
# @Author  : zc
# @Desc    : 开放平台公共部分接口的调用示例
import logging

from chanjet_openapi_python_sdk.chanjet_client import ChanjetClient
from chanjet_openapi_python_sdk.content.add_user_content import AddUserContent
from chanjet_openapi_python_sdk.content.create_order_content import CreateOrderContent
from chanjet_openapi_python_sdk.content.create_tenant_content import CreateTenantContent
from chanjet_openapi_python_sdk.content.get_app_access_token_content import GetAppAccessTokenContent
from chanjet_openapi_python_sdk.content.get_org_access_token_content import GetOrgAccessTokenContent
from chanjet_openapi_python_sdk.content.get_permanent_auth_code_content import GetPermanentAuthCodeContent
from chanjet_openapi_python_sdk.content.get_tenant_token_content import GetTenantTokenContent
from chanjet_openapi_python_sdk.content.get_token_by_permanent_code_content import GetTokenByPermanentCodeContent
from chanjet_openapi_python_sdk.content.get_user_token_content import GetUserTokenContent
from chanjet_openapi_python_sdk.content.remove_user_content import RemoveUserContent
from chanjet_openapi_python_sdk.content.trail_product_content import TrailProductContent
from chanjet_openapi_python_sdk.request.add_user_request import AddUserRequest
from chanjet_openapi_python_sdk.request.create_order_request import CreateOrderRequest
from chanjet_openapi_python_sdk.request.create_tenant_request import CreateTenantRequest
from chanjet_openapi_python_sdk.request.get_app_access_token_request import GetAppAccessTokenRequest
from chanjet_openapi_python_sdk.request.get_cia_userinfo_request import GetCIAUserinfoRequest
from chanjet_openapi_python_sdk.request.get_login_url_request import GetLoginUrlRequest
from chanjet_openapi_python_sdk.request.get_org_access_token_request import GetOrgAccessTokenRequest
from chanjet_openapi_python_sdk.request.get_permanent_auth_code_request import GetPermanentAuthCodeRequest
from chanjet_openapi_python_sdk.request.get_tenant_token_request import GetTenantTokenRequest
from chanjet_openapi_python_sdk.request.get_token_by_permanent_code_request import GetTokenByPermanentCodeRequest
from chanjet_openapi_python_sdk.request.get_token_request import GetTokenRequest
from chanjet_openapi_python_sdk.request.get_user_token_request import GetUserTokenRequest
from chanjet_openapi_python_sdk.request.refresh_token_request import RefreshTokenRequest
from chanjet_openapi_python_sdk.request.remove_user_request import RemoveUserRequest
from chanjet_openapi_python_sdk.request.trail_product_request import TrailProductRequest
from chanjet_openapi_python_sdk.response.add_user_response import AddUserResponse
from chanjet_openapi_python_sdk.response.create_order_response import CreateOrderResponse
from chanjet_openapi_python_sdk.response.create_tenant_response import CreateTenantResponse
from chanjet_openapi_python_sdk.response.get_app_access_token_response import GetAppAccessTokenResponse
from chanjet_openapi_python_sdk.response.get_cia_userinfo_response import GetCIAUserinfoResponse
from chanjet_openapi_python_sdk.response.get_login_url_response import GetLoginUrlResponse
from chanjet_openapi_python_sdk.response.get_org_access_token_response import GetOrgAccessTokenResponse
from chanjet_openapi_python_sdk.response.get_permanent_auth_code_response import GetPermanentAuthCodeResponse
from chanjet_openapi_python_sdk.response.get_tenant_token_response import GetTenantTokenResponse
from chanjet_openapi_python_sdk.response.get_token_by_permanent_code_response import GetTokenByPermanentCodeResponse
from chanjet_openapi_python_sdk.response.get_token_response import GetTokenResponse
from chanjet_openapi_python_sdk.response.get_user_token_response import GetUserTokenResponse
from chanjet_openapi_python_sdk.response.refresh_token_response import RefreshTokenResponse
from chanjet_openapi_python_sdk.response.remove_user_response import RemoveUserResponse
from chanjet_openapi_python_sdk.response.trail_product_response import TrailProductResponse
from chanjet_openapi_python_sdk.utils.chanjet_logger import ChanjetLogger


# 刷新开放平台token的示例
def refresh_token_demo(client):
    req = RefreshTokenRequest()
    req.request_uri = '/auth/refreshToken'
    params = {
        'grantType': 'refresh_token',
        'appKey': 'A5tyQHP8',
        'refreshToken': 'fd84002a8aaf44108547bc90c9ccf566'
    }
    req.add_query_params(params)
    result = client.execute(req, RefreshTokenResponse)
    return result


# 获取CIA用户信息的示例
def get_cia_userinfo_demo(client):
    req = GetCIAUserinfoRequest()
    req.request_uri = '/accounting/cia/api/v1/user'
    result = client.execute(req, GetCIAUserinfoResponse)
    return result


# 获取登录url的示例
def get_login_url_demo(client):
    req = GetLoginUrlRequest()
    req.request_uri = '/authSite/sso/getLoginUrl'
    # 业务state参数，为json字符串，需要UrlEncode
    req.add_query_params('state', '%7B%22page%22%3A%22000000%22%2C%22partnerCode%22%3A%22cjd_abc%22%7D')
    result = client.execute(req, GetLoginUrlResponse)
    return result


# 创建租户的示例
def create_tenant_demo(client):
    req = CreateTenantRequest()
    req.request_uri = '/financial/orgAndUser/createTenant'
    req.content = CreateTenantContent('test_11111111127', '测试用户1227', '测试租户名1117')
    result = client.execute(req, CreateTenantResponse)
    return result


# 企业内添加用户的示例
def add_user_demo(client):
    req = AddUserRequest()
    req.request_uri = '/financial/orgAndUser/addUser'
    req.content = AddUserContent('test_11111111127', 'user_12122', '测试租户名1117')
    result = client.execute(req, AddUserResponse)
    return result


# 企业内移除用户的示例
def remove_user_demo(client):
    req = RemoveUserRequest()
    req.request_uri = '/financial/orgAndUser/removeUser'
    req.content = RemoveUserContent('test_11111111126', 'user_12121')
    result = client.execute(req, RemoveUserResponse)
    return result


# 获取租户token的示例
def get_tenant_token_demo(client):
    req = GetTenantTokenRequest()
    req.request_uri = '/financial/auth/getTenantToken'
    req.content = GetTenantTokenContent('test_11111111126', 'accounting')
    result = client.execute(req, GetTenantTokenResponse)
    return result


# 获取用户token的示例
def get_user_token_demo(client):
    req = GetUserTokenRequest()
    req.request_uri = '/financial/auth/getUserToken'
    req.content = GetUserTokenContent('test_11111111127', 'accounting', 'user_12122')
    result = client.execute(req, GetUserTokenResponse)
    return result


# 产品试用的示例
def trail_product_demo(client):
    req = TrailProductRequest()
    req.request_uri = '/financial/order/trailProduct'
    req.content = TrailProductContent('test_11111111127', '59', 'open', '1233')
    result = client.execute(req, TrailProductResponse)
    return result


# 代客下单的示例
def create_order_demo(client):
    req = CreateOrderRequest()
    req.request_uri = '/financial/order/createOrder'
    req.content = CreateOrderContent('test_11111111127', '3961p04282', 'kfpt', '24d81a63816d457cd7d7a541dc79cee0',
                                     '5634096745A675078462D43BF58ED5F0', 'test', '221e31312312667')
    result = client.execute(req, CreateOrderResponse)
    return result


# 获取应用凭证的示例
def get_app_access_token_demo(client):
    req = GetAppAccessTokenRequest()
    req.request_uri = '/auth/appAuth/getAppAccessToken'
    req.content = GetAppAccessTokenContent('bd05ff12c9f240d3acc10f2e321c789a')
    result = client.execute(req, GetAppAccessTokenResponse)
    return result


# 获取企业永久授权码的示例
def get_permanent_auth_code_demo(client):
    req = GetPermanentAuthCodeRequest()
    req.request_uri = '/auth/orgAuth/getPermanentAuthCode'
    req.content = GetPermanentAuthCodeContent('909c1237a7cd4858a8a825afda7924bb', '961b21d4e65b4981939f2bca7fcf012b')
    result = client.execute(req, GetPermanentAuthCodeResponse)
    return result


# 获取企业凭证的示例
def get_org_access_token_demo(client):
    req = GetOrgAccessTokenRequest()
    req.request_uri = '/auth/orgAuth/getOrgAccessToken'
    req.content = GetOrgAccessTokenContent('909c1237a7cd4858a8a825afda7924bb', '961b21d4e65b4981939f2bca7fcf012b')
    result = client.execute(req, GetOrgAccessTokenResponse)
    return result


# 授权码换token的示例
def get_token_demo(client):
    req = GetTokenRequest()
    req.request_uri = '/auth/getToken'
    params = {
        'grantType': 'authorization_code',
        'appKey': 'A5tyQHP8',
        'redirectUri': 'https://t.chanjet.com',
        'code': 'ffb20d9c95e5410896c8270e49ccd43c'
    }
    req.add_query_params(params)
    result = client.execute(req, GetTokenResponse)
    return result


# 使用用户永久授权码获取token的示例
def get_token_by_permanent_code_demo(client):
    req = GetTokenByPermanentCodeRequest()
    req.request_uri = '/auth/token/getTokenByPermanentCode'
    org_access_token = 'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhY2Nlc3NfdG9rZW4iOiJtb2NrX3Rva2VuIiwic3ViIjoiaXN2IiwiYXVkIjoiaXN2IiwibmJmIjoxNjAzNzkzMTc1LCJhcHBJZCI6IjEwNjUiLCJpc3MiOiJjaGFuamV0IiwiZXhwIjoxNjAzODAwMzc1LCJ1c2VySWQiOiI2MTAwMDQyNjc1OCIsImlhdCI6MTYwMzc5MzE3NSwib3JnSWQiOiI5MDAwMTE5ODg2MiJ9.mQOtdpMaDdHavCVAcFJtutH7_J9ol1sqD5_RfBaoAKg'
    req.content = GetTokenByPermanentCodeContent(org_access_token, 'a5610cb8148c4da8a46c9fbdf3f6ff7d')
    result = client.execute(req, GetTokenByPermanentCodeResponse)
    return result


if __name__ == '__main__':
    # 设置自定义日志配置
    ChanjetLogger(logging.INFO)

    c = ChanjetClient('https://openapi.chanjet.com')
    # 请填入您从开放平台申请下来的appKey
    c.app_key = 'A******8'
    # 请填入您从开放平台申请下来的appSecret
    c.app_secret = '9****************8'
    # 请填入您的开放平台openToken
    c.open_token = """e****************************************************************************k"""

    # 刷新开放平台token
    # res = refresh_token_demo(c)

    # 获取cia用户信息
    # res = get_cia_userinfo_demo(c)

    # 获取登录url
    # res = get_login_url_demo(c)

    # 创建租户
    # res = create_tenant_demo(c)

    # 企业内添加用户
    # res = add_user_demo(c)

    # 企业内移除用户
    # res = remove_user_demo(c)

    # 获取租户token
    # res = get_tenant_token_demo(c)

    # 获取用户token
    # res = get_user_token_demo(c)

    # 产品试用
    # res = trail_product_demo(c)

    # 代客下单
    # res = create_order_demo(c)

    # 获取应用凭证
    # res = get_app_access_token_demo(c)

    # 获取企业永久授权码
    # res = get_permanent_auth_code_demo(c)

    # 获取企业凭证
    # res = get_org_access_token_demo(c)

    # 授权码换token
    # res = get_token_demo(c)

    # 授权码换token
    res = get_token_by_permanent_code_demo(c)

    print(res)

    # if res.value is None:
    #     print(res.error.__dict__)
    # else:
    #     print(res.value.__dict__)



# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 查询存货返回值实体
from chanjet_openapi_python_sdk.chanjet_response import ChanjetResponse


class QueryInventoryResponse(ChanjetResponse):

    def __init__(self, data=None):
        # 存货编码
        self.Code = ''
        # 存货名称
        self.Name = ''
        # 存货助记码
        self.Shorthand = ''
        # 存货分类
        self.InventoryClass = self.InventoryClassInfo()
        # 是否停用
        self.Disabled = ''
        # 是否销售属性
        self.IsSale = ''
        if data:
            self.__dict__ = data

    class InventoryClassInfo:

        def __init__(self):
            # 存货分类编码
            self.Code = ''
            # 存货分类名称
            self.Name = ''

    def __str__(self):
        return str(self.__dict__)



# -*- coding: utf-8 -*-
# @Time    : 2021/8/10 10:54
# @Author  : zc
# @Desc    : 获取应用凭证请求体实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 获取应用凭证请求体实体
class GetAppAccessTokenContent(ChanjetContent):

    def __init__(self, app_ticket):
        """
        获取应用凭证实体初始化方法
        :param app_ticket: 应用票据
        :type app_ticket: str
        """

        self.appTicket = app_ticket



# -*- coding: utf-8 -*-
# @Time    : 2021/8/10 11:23
# @Author  : zc
# @Desc    : 获取企业永久授权码请求体实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 获取企业永久授权码请求体实体
class GetPermanentAuthCodeContent(ChanjetContent):

    def __init__(self, app_access_token, temp_auth_code):
        """
        获取企业永久授权码初始化方法
        :param app_access_token: 应用凭证
        :type app_access_token: str
        :param temp_auth_code: 企业临时授权码
        :type temp_auth_code: str
        """

        self.appAccessToken = app_access_token
        self.tempAuthCode = temp_auth_code



# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 查询现存量返回值实体
from chanjet_openapi_python_sdk.chanjet_response import ChanjetResponse


class QueryCurrentStockResponse(ChanjetResponse):

    def __init__(self, data=None):
        self.WarehouseName = ""
        self.WarehouseCode = ""
        self.InvLocationName = ""
        self.InvLocationCode = ""
        self.InventoryCode = ""
        self.InventoryName = ""
        self.InventoryClassCode = ""
        self.InventoryClassName = ""
        self.DefaultBarCode = ""
        self.InvBarCode = ""
        self.UnitName = ""
        self.Specification = ""
        self.Brand = ""
        self.IsSingleUnit = ""
        self.AvailableQuantity = ""
        self.ExistingQuantity = ""
        self.UnitName2 = ""
        self.AvailableQuantity2 = ""
        self.ExistingQuantity2 = ""
        self.TS = ""
        self.TotalCount = ""
        self.SkuCode = ""
        self.Batch = ""
        self.ProductionDate = ""
        self.ExpiryDate = ""
        self.DynamicPropertyKeys = []
        self.DynamicPropertyTitles = []
        self.DynamicPropertyValues = []
        if data:
            self.__dict__ = data

    def __str__(self):
        return str(self.__dict__)



# -*- coding: utf-8 -*-
# @Time    : 2021/8/9 11:02
# @Author  : zc
# @Desc    : 获取CIA用户信息的返回值实体
from chanjet_openapi_python_sdk.chanjet_response import ChanjetResponse


class GetCIAUserinfoResponse(ChanjetResponse):

    def __init__(self, data=None):
        # 企业类型
        self.orgType = ''
        # 企业的全称
        self.orgFullName = ''
        # 用户备注
        self.remark = ''
        # 用户类型
        self.userType = ''
        # 登录使用的账号
        self.loginAccount = ''
        # 企业ID
        self.orgId = ''
        # 用户名
        self.username = ''
        # 用户ID
        self.userId = ''
        # 最后修改时间
        self.modifyTime = ''
        # 签名
        self.signature = ''
        # 公司名
        self.companyName = ''
        # 默认的企业ID
        self.defaultOrganization = ''
        # 是否成功
        self.result = True
        # 创建时间
        self.createTime = ''
        # 头像
        self.headPicture = ''
        # 推广来源
        self.origin = ''
        # 企业简称
        self.orgName = ''
        # 修改的次数
        self.userVersion = ''
        # 和userId一样
        self.userLongId = ''

        if data:
            self.__dict__ = data

    def __str__(self):
        return str(self.__dict__)



# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 创建生凭证请求体实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 创建生凭证请求体实体
class CreateDocContent(ChanjetContent):

    def __init__(self, voucher_date, external_code, doc_type, attached_voucher_num):
        self.dto = self.Dto(voucher_date, external_code, doc_type, attached_voucher_num)

    class Dto:

        def __init__(self, voucher_date, external_code, doc_type_code, attached_voucher_num):
            """
            凭证实体初始化方法
            :param voucher_date: 制单日期
            :type voucher_date: str
            :param external_code: 外部编码
            :type external_code: str
            :param doc_type_code: 凭证类别编码
            :type doc_type_code: str
            :param attached_voucher_num: 附单据数
            :type attached_voucher_num: str
            """

            self.VoucherDate = voucher_date
            self.ExternalCode = external_code
            self.DocType = self.DocTypeInfo(doc_type_code)
            self.AttachedVoucherNum = attached_voucher_num
            self.Entrys = []

        class DocTypeInfo:

            def __init__(self, doc_type_code):
                self.Code = doc_type_code


# 凭证明细实体
class Entry:

    def __init__(self, summary, account_code, currency_code, amount, is_cr=True):
        """
        凭证明细实体初始化方法
        :param summary: 摘要
        :type summary: str
        :param account_code: 科目编号
        :type account_code: str
        :param currency_code: 货币编号
        :type currency_code: str
        :param amount: 本币
        :type amount: str
        :param is_cr: 是否为贷方，如果为False则为借方
        :type is_cr: bool
        """

        self.Summary = summary
        self.Account = self.AccountInfo(account_code)
        self.Currency = self.CurrencyInfo(currency_code)
        if is_cr:
            self.AmountCr = amount
        else:
            self.AmountDr = amount
        self.AuxInfos = []

    class AccountInfo:

        def __init__(self, account_code):
            self.Code = account_code

    class CurrencyInfo:

        def __init__(self, currency_code):
            self.Code = currency_code


# 辅助核算项实体
class AuxInfo:

    def __init__(self, settle_style_code, bank_account_code, aux_acc_inventory_code):
        """
        辅助核算项实体初始化方法
        :param settle_style_code: 结算方式编码
        :type settle_style_code: str
        :param bank_account_code: 账号编码
        :type bank_account_code: str
        :param aux_acc_inventory_code: 存货编码
        :type aux_acc_inventory_code: str
        """

        self.SettleStyle = self.SettleStyleInfo(settle_style_code)
        self.BankAccount = self.BankAccountInfo(bank_account_code)
        self.AuxAccInventory = self.AuxAccInventoryInfo(aux_acc_inventory_code)

    class SettleStyleInfo:

        def __init__(self, settle_style_code):
            self.Code = settle_style_code

    class BankAccountInfo:

        def __init__(self, bank_account_code):
            self.Code = bank_account_code

    class AuxAccInventoryInfo:

        def __init__(self, aux_acc_inventory_code):
            self.Code = aux_acc_inventory_code



# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 创建存货请求类
from chanjet_openapi_python_sdk.chanjet_request import ChanjetRequest


class CreateInventoryRequest(ChanjetRequest):

    def get_http_method(self):
        return 'post'



# -*- coding: utf-8 -*-
# @Time    : 2021/8/10 10:18
# @Author  : zc
# @Desc    : 代客下单请求体实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 代客下单请求体实体
class CreateOrderContent(ChanjetContent):

    def __init__(self, tenant_id, product_id, agent_pwd, agent_pay_pwd, agent_code, third_order_no, description):
        """
        代客下单实体初始化方法
        :param tenant_id: 租户ID
        :type tenant_id: str
        :param product_id: 产品ID
        :type product_id: str
        :param agent_pwd: 服务商登录密码
        :type agent_pwd: str
        :param agent_pay_pwd: 服务商支付密码
        :type agent_pay_pwd: str
        :param agent_code: 服务商编码
        :type agent_code: str
        :param third_order_no: 第三方订单号
        :type third_order_no: str
        :param description: 订单描述
        :type description: str
        """

        self.tenantId = tenant_id
        self.productId = product_id
        self.agentPwd = agent_pwd
        self.agentPayPwd = agent_pay_pwd
        self.agentCode = agent_code
        self.thirdOrderNo = third_order_no
        self.description = description



# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 畅捷通开放平台客户端
import json
import logging

import requests

from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent
from chanjet_openapi_python_sdk.chanjet_response import ChanjetResponse
from chanjet_openapi_python_sdk.exception.http_method_exception import HttpMethodException
from chanjet_openapi_python_sdk.exception.serialize_response_exception import SerializeResponseException


class ChanjetClient:

    def __init__(self, server_url, app_key='', app_secret='', open_token='', content_type='application/json', connect_timeout=3, read_timeout=15):
        self._server_url = server_url
        self._content_type = content_type
        self._open_token = open_token
        self._app_key = app_key
        self._app_secret = app_secret
        self._headers = {}
        # 设置链接超时时长，单位s
        self._connect_timeout = connect_timeout
        # 设置接口响应超时时长，单位s
        self._read_timeout = read_timeout
        # 请求方法对应的执行函数
        self._http_method_func = {
            'get': self._do_get,
            'post': self._do_post,
            'put': self._do_put,
            'delete': self._do_delete
        }

    # 获取请求头参数
    def get_request_headers(self):
        self._headers['appKey'] = self._app_key
        self._headers['appSecret'] = self._app_secret
        self._headers['openToken'] = self._open_token
        self._headers['Content-Type'] = self._content_type
        return self._headers

    # 设置请求头参数
    def add_request_headers(self, headers):
        self._headers.update(headers)

    # 设置单个请求头参数
    def add_request_header(self, key, value):
        self._headers[key] = value

    # 获取请求头app_key
    @property
    def app_key(self):
        return self._app_key

    # 设置请求头app_key
    @app_key.setter
    def app_key(self, app_key):
        self._app_key = app_key

    # 获取请求头app_secret
    @property
    def app_secret(self):
        return self._app_secret

    # 设置请求头app_secret
    @app_secret.setter
    def app_secret(self, app_secret):
        self._app_secret = app_secret

    # 获取请求头open_token
    @property
    def open_token(self):
        return self._open_token

    # 设置请求头open_token
    @open_token.setter
    def open_token(self, open_token):
        self._open_token = open_token

    # 获取请求头content_type
    @property
    def content_type(self):
        return self._content_type

    # 设置请求头content_type
    @content_type.setter
    def content_type(self, content_type):
        self._content_type = content_type

    # http异常处理方法
    def _handle_exception(self, res):
        try:
            res.raise_for_status()
            return True
        except requests.exceptions.HTTPError as e:
            logging.error(f'http请求错误: {e}')

    # post请求
    def _do_post(self, req):
        return requests.post(self._server_url + req.request_uri,
                             json=req.content,
                             headers=self.get_request_headers(),
                             timeout=(self._connect_timeout, self._read_timeout))

    # get请求
    def _do_get(self, req):
        return requests.get(self._server_url + req.request_uri,
                            params=req.get_query_params(),
                            headers=self.get_request_headers(),
                            timeout=(self._connect_timeout, self._read_timeout))

    # put请求
    def _do_put(self, req):
        return requests.put(self._server_url + req.request_uri,
                            json=req.content,
                            headers=self.get_request_headers(),
                            timeout=(self._connect_timeout, self._read_timeout))

    # delete请求
    def _do_delete(self, req):
        return requests.delete(self._server_url + req.request_uri,
                               params=req.get_query_params(),
                               headers=self.get_request_headers(),
                               timeout=(self._connect_timeout, self._read_timeout))

    # 执行请求的方法
    def execute(self, req, response_class=None):
        # 从request对象上获取请求方法，并找到对应的处理方法
        http_method = req.get_http_method().lower()
        func = self._http_method_func.get(http_method, False)
        if not func:
            raise HttpMethodException('仅支持get、post、put、delete请求方法')

        # 如果请求体是Content对象，则将对象转化为字典
        if isinstance(req.content, ChanjetContent):
            req.content = json.loads(json.dumps(req.content, default=lambda obj: obj.__dict__))

        logging.info(f'url: {self._server_url + req.request_uri}')
        logging.info(f'request-header: {str(self.get_request_headers())}')
        if http_method in ['get', 'delete']:
            logging.info(f'request-params: {str(req.get_query_params())}')
        else:
            logging.info(f'request-content: {str(req.content)}')

        # 发起请求
        res = func(req)
        self._handle_exception(res)

        # 如果传入Response类，则返回该类的实例并绑定返回数据，否则返回dict数据
        result = None
        if response_class:
            if issubclass(response_class, ChanjetResponse):
                result = json.loads(res.text, object_hook=response_class)
            else:
                raise SerializeResponseException(f"传入的'{response_class.__name__}'类不是'ChanjetResponse'的子类")
        else:
            result = json.loads(res.text)
        return result



# -*- coding: utf-8 -*-
# @Time    : 2021/8/9 14:05
# @Author  : zc
# @Desc    : 刷新开放平台token的返回值实体
from chanjet_openapi_python_sdk.chanjet_response import ChanjetResponse


class RefreshTokenResponse(ChanjetResponse):

    def __init__(self, data=None):
        # 返回code码，200为成功，其余均为失败
        self.code = ''
        # 描述信息
        self.message = ''
        # 返回结果
        self.result = self.Result()

        if data:
            self.__dict__ = data

    def __str__(self):
        return str(self.__dict__)

    class Result:

        def __init__(self):
            # 访问令牌
            self.access_token = ''
            # 过期时间，单位s
            self.expires_in = ''
            # 更新令牌
            self.refresh_token = ''
            # 更新令牌过期时间，单位s
            self.refresh_expires_in = ''
            # 授权域
            self.scope = ''
            # 用户ID
            self.user_id = ''
            # 企业ID
            self.org_id = ''
            # 应用名
            self.app_name = ''
            # T + 产品部分接口需要传在Cookie中的值
            self.sid = ''



# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 查询往来单位返回值实体
from chanjet_openapi_python_sdk.chanjet_response import ChanjetResponse


class QueryPartnerResponse(ChanjetResponse):

    def __init__(self, data=None):
        # 往来单位编码
        self.Code = ''
        # 往来单位名称
        self.Name = ''
        # 往来单位助记码
        self.ShortHand = ''
        # 往来单位分类
        self.PartnerClass = self.PartnerClassInfo()
        # 往来单位是否停用
        self.Disabled = ''
        if data:
            self.__dict__ = data

    class PartnerClassInfo:

        def __init__(self):
            # 往来单位分类编码
            self.Code = ''
            # 往来单位分类名称
            self.Name = ''

    def __str__(self):
        return str(self.__dict__)




# -*- coding: utf-8 -*-
# @Time    : 2021/8/10 16:50
# @Author  : zc
# @Desc    : 使用用户永久授权码获取token请求体实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 使用用户永久授权码获取token请求体实体
class GetTokenByPermanentCodeContent(ChanjetContent):

    def __init__(self, org_access_token, user_auth_permanent_code):
        """
        使用用户永久授权码获取token初始化方法
        :param org_access_token: 应用凭证
        :type org_access_token: str
        :param user_auth_permanent_code: 企业永久授权码
        :type user_auth_permanent_code: str
        """

        self.orgAccessToken = org_access_token
        self.userAuthPermanentCode = user_auth_permanent_code



# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 通用报表查询条件的请求体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 通用报表查询条件的请求体
class QueryReportDataContent(ChanjetContent):

    def __init__(self, report_name, page_index, page_size):
        self.request = self.Request(report_name, page_index, page_size)

    class Request:

        def __init__(self, report_name, page_index, page_size):
            """
            通用报表查询条件实体初始化方法
            :param report_name: 报表名称
            :type report_name: str
            :param page_index: 当前页码
            :type page_index: int
            :param page_size: 每页显示数量
            :type page_size: int
            """

            self.ReportName = report_name
            self.PageIndex = page_index
            self.PageSize = page_size
            # 查询项
            self.SearchItems = []
            # 需要显示的栏目
            self.ReportTableColNames = 'VoucherDate,saleDeliveryCode,partnerCode,partnerName'


class SearchItem:

    def __init__(self, column_name, begin_default, begin_default_text, end_default, end_default_text):
        """
        通用报表查询项实体初始化方法
        :param column_name: 列名
        :type column_name: str
        :param begin_default: 开始默认值
        :type begin_default: str
        :param begin_default_text: 开始默认值
        :type begin_default_text: str
        :param end_default: 结束默认值
        :type end_default: str
        :param end_default_text: 结束默认值
        :type end_default_text: str
        """

        self.ColumnName = column_name
        self.BeginDefault = begin_default
        self.BeginDefaultText = begin_default_text
        self.EndDefault = end_default
        self.EndDefaultText = end_default_text



# -*- coding: utf-8 -*-
# @Time    : 2021/8/11 9:17
# @Author  : zc
# @Desc    : 自定义日志配置器
import logging


class ChanjetLogger:

    def __init__(self, level):
        log_format = "%(asctime)s - %(levelname)s - %(message)s"
        logging.basicConfig(level=logging.DEBUG, format=log_format)



# -*- coding: utf-8 -*-
# @Time    : 2021/8/9 13:43
# @Author  : zc
# @Desc    : 刷新开放平台token的请求参数实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 刷新开放平台token的请求参数实体
class RefreshTokenContent(ChanjetContent):

    def __init__(self, app_key, refresh_token):
        """
        刷新开放平台token的请求参数实体初始化方法
        :param app_key: 开放平台的appKey
        :type app_key: str
        :param refresh_token: 刷新令牌
        :type refresh_token: str
        """

        # 授权类型，固定填refresh_token
        self.grantType = 'refresh_token'
        self.appKey = app_key
        self.refreshToken = refresh_token



# -*- coding: utf-8 -*-
# @Time    : 2021/8/9 15:17
# @Author  : zc
# @Desc    : 创建租户请求体实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 创建租户请求体实体
class CreateTenantContent(ChanjetContent):

    def __init__(self, tenant_id, name, tenant_full_name):
        """
        创建租户实体初始化方法
        :param tenant_id: 租户ID
        :type tenant_id: str
        :param name: 创建人用户名称
        :type name: str
        :param tenant_full_name: 企业名称，全局必须唯一
        :type tenant_full_name: str
        """

        self.tenantId = tenant_id
        self.name = name
        self.tenantFullName = tenant_full_name



# -*- coding: utf-8 -*-
# @Time    : 2021/8/9 15:26
# @Author  : zc
# @Desc    : 创建租户返回值实体
from chanjet_openapi_python_sdk.chanjet_response import ChanjetResponse


class CreateTenantResponse(ChanjetResponse):

    def __init__(self, data=None):
        # 是否成功
        self.result = ''
        # 响应内容
        self.value = self.Value()
        # 错误信息，result为true时为null
        self.error = self.Error()

        if data:
            self.__dict__ = data

    def __str__(self):
        return str(self.__dict__)

    class Error:

        def __init__(self):
            # 错误码
            self.code = 0
            # 错误信息
            self.msg = ''
            # 错误提示
            self.hint = ''

    class Value:

        def __init__(self):
            # 畅捷通企业ID
            self.orgId = ''
            # 畅捷通用户ID
            self.userId = ''



# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 存货查询条件的请求实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 存货查询条件的请求实体
class QueryInventoryContent(ChanjetContent):

    def __init__(self, code, inventory_class_code, is_stop, is_sale):
        self.param = self.Params(code, inventory_class_code, is_stop, is_sale)

    class Params:

        def __init__(self, code, inventory_class_code, is_stop, is_sale):
            """
            存货查询条件实体初始化方法
            :param code: 存货编码
            :type code: str
            :param inventory_class_code: 存货分类编码
            :type inventory_class_code: str
            :param is_stop: 是否停用
            :type is_stop: bool
            :param is_sale: 是否销售属性
            :type is_sale: bool
            """

            self.Code = code
            self.InventoryClass = self.InventoryClassInfo(inventory_class_code)
            self.Disabled = is_stop
            self.IsSale = is_sale
            # 需要返回的字段名
            self.SelectFields = 'Code,Name,Shorthand,InventoryClass.Code,InventoryClass.Name,Disabled,IsSale'

        class InventoryClassInfo:

            def __init__(self, code):
                self.Code = code



# -*- coding: utf-8 -*-
# @Time    : 2021/8/10 9:54
# @Author  : zc
# @Desc    : 产品试用请求体实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 产品试用请求体实体
class TrailProductContent(ChanjetContent):

    def __init__(self, tenant_id, product_id, agent_code, referee_name):
        """
        产品试用实体初始化方法
        :param tenant_id: 租户ID
        :type tenant_id: str
        :param product_id: 产品ID
        :type product_id: str
        :param agent_code: 服务商编码，沙箱环境传w
        :type agent_code: str
        :param referee_name: 推荐码
        :type referee_name: str
        """

        self.tenantId = tenant_id
        self.productId = product_id
        self.agentCode = agent_code
        self.refereeName = referee_name



from setuptools import setup


with open('README.md', encoding='utf-8') as fh:
    long_description = fh.read()

setup(
    name="chanjet-openapi-python-sdk",
    version="1.0.2",
    author="zc",
    author_email="zhaochang1@chanjet.com",
    description="畅捷通开放平台python版sdk",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="MIT",
    url="https://github.com/Chanjet/chanjet-openapi-python-sdk",
    packages=[
        'chanjet_openapi_python_sdk',
        'chanjet_openapi_python_sdk.content',
        'chanjet_openapi_python_sdk.content.tplus',
        'chanjet_openapi_python_sdk.exception',
        'chanjet_openapi_python_sdk.request',
        'chanjet_openapi_python_sdk.request.tplus',
        'chanjet_openapi_python_sdk.response',
        'chanjet_openapi_python_sdk.response.tplus',
        'chanjet_openapi_python_sdk.utils'
    ],
    install_requires=['requests==2.26.0'],
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)



# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 畅捷通开放平台Request基类
from chanjet_openapi_python_sdk.exception.http_method_exception import HttpMethodException


class ChanjetRequest:

    def __init__(self, request_uri=''):
        self._query_params = {}
        self._request_uri = request_uri
        self._content = None

    # 获取请求参数
    def get_query_params(self):
        return self._query_params

    # 添加多个请求参数
    def add_query_params(self, query_params):
        self._query_params.update(query_params)

    # 添加单个请求参数
    def add_query_param(self, key, value):
        self._query_params[key] = value

    # 获取请求uri
    @property
    def request_uri(self):
        return self._request_uri

    # 设置请求uri
    @request_uri.setter
    def request_uri(self, request_uri):
        self._request_uri = request_uri

    # 获取请求体内容
    @property
    def content(self):
        return self._content

    # 设置请求体内容
    @content.setter
    def content(self, content):
        self._content = content

    # 获取http请求方法名
    def get_http_method(self):
        raise HttpMethodException('请重写父类的get_http_method方法')



# -*- coding: utf-8 -*-
# @Time    : 2021/8/10 11:02
# @Author  : zc
# @Desc    : 获取应用凭证返回值实体
from chanjet_openapi_python_sdk.chanjet_response import ChanjetResponse


class GetAppAccessTokenResponse(ChanjetResponse):

    def __init__(self, data=None):
        # 错误码，200为成功，其余均为失败
        self.code = ''
        # 错误提示信息
        self.message = ''
        # 返回结果
        self.result = self.Result()

        if data:
            self.__dict__ = data

    def __str__(self):
        return str(self.__dict__)

    class Result:

        def __init__(self):
            # 应用凭证
            self.appAccessToken = ''
            # 过期时间
            self.expireTime = 0



# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 往来单位查询条件的请求实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 往来单位查询条件的请求实体
class QueryPartnerContent(ChanjetContent):

    def __init__(self, code, name, made_record_date):
        self.param = self.Params(code, name, made_record_date)

    class Params:

        def __init__(self, code, name, made_record_date):
            """
            往来单位查询条件实体初始化方法
            :param code: 往来单位编码
            :type code: str
            :param name: 往来单位名称
            :type name: str
            :param made_record_date: 建档日期
            :type made_record_date: str
            """

            self.Code = code
            self.Name = name
            self.MadeRecordDate = made_record_date
            self.SelectFields = 'Code,Name,ShortHand,PartnerClass.Code,PartnerClass.Name,Disabled'



# -*- coding: utf-8 -*-
# @Time    : 2021/8/9 15:43
# @Author  : zc
# @Desc    : 企业内添加用户请求体实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 企业内添加用户请求体实体
class AddUserContent(ChanjetContent):

    def __init__(self, tenant_id, third_platform_user_id, name):
        """
        企业内添加用户实体初始化方法
        :param tenant_id: 租户ID
        :type tenant_id: str
        :param third_platform_user_id: 第三方用户ID
        :type third_platform_user_id: str
        :param name: 用户名称
        :type name: str
        """

        self.tenantId = tenant_id
        self.thirdPlatformUserId = third_platform_user_id
        self.name = name




# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 畅捷通开放平台T+部分接口的调用示例
import logging

from chanjet_openapi_python_sdk.chanjet_client import ChanjetClient
from chanjet_openapi_python_sdk.content.tplus.create_doc_content import AuxInfo, Entry, CreateDocContent
from chanjet_openapi_python_sdk.content.tplus.create_inventory_content import CreateInventoryContent
from chanjet_openapi_python_sdk.content.tplus.create_partner_content import CreatePartnerContent
from chanjet_openapi_python_sdk.content.tplus.create_sale_delivery_contect import CreateSaleDeliveryContent, SaleDeliveryDetail
from chanjet_openapi_python_sdk.content.tplus.create_sale_order_content import SaleOrderDetail, CreateSaleOrderContent
from chanjet_openapi_python_sdk.content.tplus.query_current_stock_content import QueryCurrentStockContent
from chanjet_openapi_python_sdk.content.tplus.query_partner_content import QueryPartnerContent
from chanjet_openapi_python_sdk.content.tplus.query_report_data_content import SearchItem, QueryReportDataContent
from chanjet_openapi_python_sdk.request.tplus.create_doc_request import CreateDocRequest
from chanjet_openapi_python_sdk.request.tplus.create_inventory_request import CreateInventoryRequest
from chanjet_openapi_python_sdk.request.tplus.create_sale_delivery_request import CreateSaleDeliveryRequest
from chanjet_openapi_python_sdk.request.tplus.create_sale_order_request import CreateSaleOrderRequest
from chanjet_openapi_python_sdk.request.tplus.query_current_stock_request import QueryCurrentStockRequest
from chanjet_openapi_python_sdk.request.tplus.query_inventory_request import QueryInventoryRequest
from chanjet_openapi_python_sdk.request.tplus.query_partner_request import QueryPartnerRequest
from chanjet_openapi_python_sdk.request.tplus.query_report_data_request import QueryReportDataRequest
from chanjet_openapi_python_sdk.response.tplus.query_current_stock_response import QueryCurrentStockResponse
from chanjet_openapi_python_sdk.response.tplus.query_inventory_response import QueryInventoryResponse
from chanjet_openapi_python_sdk.content.tplus.query_inventory_content import QueryInventoryContent
from chanjet_openapi_python_sdk.response.tplus.query_partner_response import QueryPartnerResponse
from chanjet_openapi_python_sdk.response.tplus.query_report_data_response import QueryReportDataResponse
from chanjet_openapi_python_sdk.utils.chanjet_logger import ChanjetLogger


# 查询存货示例
def query_inventory_demo(client):
    req = QueryInventoryRequest()
    req.request_uri = '/tplus/api/v2/inventory/Query'
    # 推荐使用字典传值方式，直接传实体实例会有一定的性能损耗
    # req.content = {'param': {'Code': '123'}}
    req.content = QueryInventoryContent('124', '123', False, True)
    # 支持将返回值解析成实体类属性，如果不传入实体类名，则按照json的格式进行转换成字典、列表、字符串等
    result = client.execute(req, QueryInventoryResponse)
    return result


# 创建存货示例
def create_inventory_demo(client):
    req = CreateInventoryRequest()
    req.request_uri = '/tplus/api/v2/inventory/Create'
    req.content = CreateInventoryContent('01001', '中南海1mg', 'ZNH1mg', '10mg', '10', '2', '个', 'false', 'true', 'true',
                                         'true')
    # 由于该接口创建存货成功后会返回null，所以不用额外定义返回值实体
    result = client.execute(req)
    return result


# 查询往来单位示例
def query_partner_demo(client):
    req = QueryPartnerRequest()
    req.request_uri = '/tplus/api/v2/partner/Query'
    req.content = QueryPartnerContent('0010003', '往来单位03', "2021-08-05")
    result = client.execute(req, QueryPartnerResponse)
    return result


# 创建往来单位示例
def create_partner_demo(client):
    req = CreateInventoryRequest()
    req.request_uri = '/tplus/api/v2/partner/Create'
    req.content = CreatePartnerContent('00101', '河北电力公司', 'HBDLGS', '河北电力公司', '01', '001')
    result = client.execute(req)
    return result


# 创建销货单示例
def create_sale_delivery_demo(client):
    req = CreateSaleDeliveryRequest()
    req.request_uri = '/tplus/api/v2/saleDelivery/Create'
    detail = SaleDeliveryDetail('01001', '个', 5, 6.4, 90, ['priuserdefnvc1', 'priuserdefdecm1'], ['sn001', '123'])
    sale_delivery = CreateSaleDeliveryContent('2021-08-05', 'Taobao-2020061503344001', '0010001', '01', '北京市海淀区',
                                              '张三', '13611111111', ['priuserdefnvc1', 'priuserdefdecm1'], ['h001', '111'])
    sale_delivery.dto.SaleDeliveryDetails.append(detail)
    req.content = sale_delivery
    result = client.execute(req)
    return result


# 创建销货订单示例
def create_sale_order_demo(client):
    req = CreateSaleOrderRequest()
    req.request_uri = '/tplus/api/v2/saleOrder/Create'
    detail = SaleOrderDetail('01001', '个', 5, 6.4, ['priuserdefnvc1', 'priuserdefdecm1'], ['sn001', '123'])
    sale_order = CreateSaleOrderContent('2021-08-05', 'Taobao-2020061503344002', '0010001', '北京市海淀区',
                                        '张三', '13611111111', ['isautoaudit'], [True])
    sale_order.dto.SaleOrderDetails.append(detail)
    req.content = sale_order
    result = client.execute(req)
    return result


# 查询指定仓库、指定存货的现存量示例
def query_current_stock_content_demo(client):
    req = QueryCurrentStockRequest()
    req.request_uri = '/tplus/api/v2/currentStock/Query'
    req.content = QueryCurrentStockContent('0001', '01001', 20, 1, True, True, True)
    result = client.execute(req, QueryCurrentStockResponse)
    return result


# 创建凭证的示例
def create_doc_demo(client):
    req = CreateDocRequest()
    aux_info = AuxInfo('1', '0102', '01001')
    entry_cr = Entry('提现', '1001', 'RMB', '100')
    entry_dr = Entry('提现', '1002', 'RMB', '100', False)
    doc_content = CreateDocContent('2021-08-06', '1', '记', 2)
    entry_dr.AuxInfos.append(aux_info)
    doc_content.dto.Entrys.extend([entry_cr, entry_dr])
    req.request_uri = '/tplus/api/v2/doc/Create'
    req.content = doc_content
    result = client.execute(req)
    return result


# 简单报表查询
def query_report_data_demo(client):
    req = QueryReportDataRequest()
    req.request_uri = '/tplus/api/v2/reportQuery/GetReportData'
    search_item = SearchItem('VoucherDate', '2021-08-06', '2021-08-06', '2021-08-06', '2021-08-06')
    query_report_data_content = QueryReportDataContent('SA_SaleDeliveryDetailRpt', 1, 4)
    query_report_data_content.request.SearchItems.append(search_item)
    req.content = query_report_data_content
    result = client.execute(req, QueryReportDataResponse)
    return result


if __name__ == '__main__':
    # 设置自定义日志配置
    ChanjetLogger(logging.INFO)

    c = ChanjetClient('https://openapi.chanjet.com')
    # 请填入您从开放平台申请下来的appKey
    c.app_key = 'A******8'
    # 请填入您从开放平台申请下来的appSecret
    c.app_secret = '9****************8'
    # 请填入您的开放平台openToken
    c.open_token = """e****************************************************************************k"""

    # 查询存货
    # res = query_inventory_demo(c)

    # 查询往来单位
    # res = query_partner_demo(c)

    # 创建存货
    # res = create_inventory_demo(c)

    # 创建往来单位
    # res = create_partner_demo(c)

    # 创建销货单
    # res = create_sale_delivery_demo(c)

    # 创建销售订单
    # res = create_sale_order_demo(c)

    # 查询指定仓库、指定存货的现存量
    # res = query_current_stock_content_demo(c)

    # 创建凭证
    # res = create_doc_demo(c)

    # 查询报表数据
    res = query_report_data_demo(c)
    print(res)



# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : 创建存货请求体实体
from chanjet_openapi_python_sdk.chanjet_content import ChanjetContent


# 创建存货请求体实体
class CreateInventoryContent(ChanjetContent):

    def __init__(self, code, name, shorthand, specification, inventory_class_code, unit_code, unit_name, disabled,
                 is_single_unit, is_purchase, is_sale):
        self.dto = self.Dto(code, name, shorthand, specification, inventory_class_code, unit_code, unit_name, disabled,
                            is_single_unit, is_purchase, is_sale)

    class Dto:

        def __init__(self, code, name, shorthand, specification, inventory_class_code, unit_code, unit_name, disabled,
                     is_single_unit, is_purchase, is_sale):
            """
            存货实体初始化方法
            :param code: 存货编码
            :type code: str
            :param name: 存货名称
            :type name: str
            :param shorthand: 助记码
            :type shorthand: str
            :param specification: 规格型号
            :type specification: str
            :param inventory_class_code: 存货分类编码
            :type inventory_class_code: str
            :param unit_code: 计量单位编码
            :type unit_code: str
            :param unit_name: 计量单位名
            :type unit_name: str
            :param disabled: 是否停用
            :type disabled: str
            :param is_single_unit: 是否单计量
            :type is_single_unit: str
            :param is_purchase: 是否外购
            :type is_purchase: str
            :param is_sale: 是否销售
            :type is_sale: str
            """

            self.Code = code
            self.Name = name
            self.Shorthand = shorthand
            self.Specification = specification
            self.InventoryClass = self.InventoryClassInfo(inventory_class_code)
            self.Unit = self.UnitInfo(unit_code, unit_name)
            self.Disabled = disabled
            self.IsSingleUnit = is_single_unit
            self.IsPurchase = is_purchase
            self.IsSale = is_sale

        class InventoryClassInfo:

            def __init__(self, inventory_class_code):
                self.Code = inventory_class_code

        class UnitInfo:

            def __init__(self, unit_code, unit_name):
                self.Code = unit_code
                self.Name = unit_name



# -*- coding: utf-8 -*-
# @Time    : 2021/8/6 15:01
# @Author  : zc
# @Desc    : json格式的response序列化成实例对象异常


class SerializeResponseException(Exception):
    def __init__(self, err_msg):
        super().__init__(self, err_msg)
